@@ -8,6 +8,8 @@
 #ifndef INCLUDED_IXION_FORMULA_OPCODE_HPP
 #define INCLUDED_IXION_FORMULA_OPCODE_HPP
 
+#include <iosfwd>
+
 namespace ixion {
 
 /** formula opcode type */
@@ -23,6 +25,7 @@ enum fopcode_t
     fop_string,
     fop_value,
     fop_function,
+    fop_error,
 
     // arithmetic operators
     fop_plus,
@@ -51,9 +54,11 @@ enum fopcode_t
     fop_array_close,
 
     // special conditions
-    fop_error, //< used to signify a special set of tokens representing formula cell with error.
+    fop_invalid_formula, //< used to signify a special set of tokens representing formula cell with error.
 };
 
+std::ostream& operator<<(std::ostream& os, fopcode_t oc);
+
 }
 
 #endif
