@@ -166,24 +166,24 @@ void get_result_from_cell(const model_context& cxt, const abs_address_t& addr, f
 {
     switch (cxt.get_celltype(addr))
     {
-        case celltype_t::formula:
+        case cell_t::formula:
         {
             res = cxt.get_formula_result(addr);
             break;
         }
-        case celltype_t::boolean:
+        case cell_t::boolean:
             res.set_boolean(cxt.get_boolean_value(addr));
             break;
-        case celltype_t::numeric:
+        case cell_t::numeric:
             res.set_value(cxt.get_numeric_value(addr));
             break;
-        case celltype_t::string:
+        case cell_t::string:
         {
             std::string_view s = cxt.get_string_value(addr);
             res.set_string_value(std::string{s});
             break;
         }
-        case celltype_t::unknown:
+        case cell_t::unknown:
         default:
             ;
     }
@@ -355,6 +355,8 @@ std::optional<stack_value> pop_stack_value(const model_context& cxt, formula_val
             return stack_value{stack.pop_string()};
         case stack_value_t::matrix:
             return stack_value{stack.pop_matrix()};
+        case stack_value_t::error:
+            return stack_value{stack.pop_error()};
         case stack_value_t::single_ref:
         {
             const abs_address_t& addr = stack.pop_single_ref();
@@ -362,21 +364,21 @@ std::optional<stack_value> pop_stack_value(const model_context& cxt, formula_val
 
             switch (ca.get_type())
             {
-                case celltype_t::empty:
+                case cell_t::empty:
                 {
                     // empty cell has a value of 0.
                     return stack_value{0.0};
                 }
-                case celltype_t::boolean:
+                case cell_t::boolean:
                     // TODO : Decide whether we need to treat this as a
                     // distinct boolean value.  For now, let's treat this as a
                     // numeric value equivalent.
-                case celltype_t::numeric:
+                case cell_t::numeric:
                 {
                     double val = ca.get_numeric_value();
                     return stack_value{val};
                 }
-                case celltype_t::string:
+                case cell_t::string:
                 {
                     std::size_t strid = ca.get_string_identifier();
                     const std::string* ps = cxt.get_string(strid);
@@ -388,7 +390,7 @@ std::optional<stack_value> pop_stack_value(const model_context& cxt, formula_val
 
                     return stack_value{*ps};
                 }
-                case celltype_t::formula:
+                case cell_t::formula:
                 {
                     formula_result res = ca.get_formula_result();
 
@@ -401,17 +403,22 @@ std::optional<stack_value> pop_stack_value(const model_context& cxt, formula_val
                         case formula_result::result_type::string:
                             return stack_value{res.get_string()};
                         case formula_result::result_type::error:
-                        default:
-                            return {};
+                            return stack_value{res.get_error()};
+                        case formula_result::result_type::matrix:
+                            IXION_DEBUG("matrix formula result type not handled yet");
                     }
                 }
-                default:
+                case cell_t::unknown:
+                {
+                    IXION_DEBUG("unknown cell type in resolving a single ref");
                     return {};
+                }
             }
             break;
         }
         case stack_value_t::range_ref:
-        default:;
+        default:
+            IXION_DEBUG("unhandled stack value type: " << stack.get_type());
     }
 
     return {};
@@ -1110,12 +1117,15 @@ void formula_interpreter::expression()
     {
         fopcode_t oc = token().opcode;
         if (!valid_expression_op(oc))
+        {
+            IXION_TRACE("expression ends with " << oc);
             return;
+        }
 
         auto sv1 = pop_stack_value(m_context, get_stack());
         if (!sv1)
         {
-            IXION_DEBUG("failed to pop value from the stack");
+            IXION_DEBUG("failed to pop value 1 from the stack");
             throw formula_error(formula_error_t::general_error);
         }
 
@@ -1128,7 +1138,7 @@ void formula_interpreter::expression()
         auto sv2 = pop_stack_value(m_context, get_stack());
         if (!sv2)
         {
-            IXION_DEBUG("failed to pop value from the stack");
+            IXION_DEBUG("failed to pop value 2 from the stack");
             throw formula_error(formula_error_t::general_error);
         }
 
@@ -1154,6 +1164,11 @@ void formula_interpreter::expression()
                         compare_value_to_matrix(get_stack(), oc, sv1->get_value(), sv2->get_matrix());
                         break;
                     }
+                    case stack_value_t::error:
+                    {
+                        get_stack().push_error(sv2->get_error());
+                        break;
+                    }
                     default:
                     {
                         IXION_DEBUG("unsupported value type for value 2: " << sv2->get_type());
@@ -1203,6 +1218,11 @@ void formula_interpreter::expression()
                 }
                 break;
             }
+            case stack_value_t::error:
+            {
+                get_stack().push_error(sv1->get_error());
+                break;
+            }
             default:
             {
                 IXION_DEBUG("unsupported value type for value 1: " << sv1->get_type());
@@ -1301,9 +1321,9 @@ void formula_interpreter::term()
 
 void formula_interpreter::factor()
 {
-    // <constant> || <variable> || '(' <expression> ')' || <function>
+    // <constant> || <error> || <variable> || '(' <expression> ')' || <function>
 
-    bool negative_sign = sign(); // NB: may be precedeed by a '+' or '-' sign.
+    bool negative_sign = sign(); // NB: may be preceded by a '+' or '-' sign.
     fopcode_t oc = token().opcode;
 
     switch (oc)
@@ -1322,6 +1342,11 @@ void formula_interpreter::factor()
             constant();
             break;
         }
+        case fop_error:
+        {
+            error();
+            break;
+        }
         case fop_single_ref:
             single_ref();
             break;
@@ -1343,7 +1368,7 @@ void formula_interpreter::factor()
         default:
         {
             std::ostringstream os;
-            os << "factor: unexpected token type: <" << get_opcode_name(oc) << ">";
+            os << "factor: unexpected token type: <" << get_formula_opcode_name(oc) << ">";
             throw invalid_expression(os.str());
         }
     }
@@ -1484,6 +1509,15 @@ void formula_interpreter::constant()
         mp_handler->push_value(val);
 }
 
+void formula_interpreter::error()
+{
+    auto err = std::get<formula_error_t>(token().value);
+    next();
+    get_stack().push_error(err);
+    if (mp_handler)
+        mp_handler->push_error(err);
+}
+
 void formula_interpreter::literal()
 {
     const std::string& s = string_or_throw();
@@ -1656,7 +1690,7 @@ void formula_interpreter::array()
             default:
             {
                 std::ostringstream os;
-                os << "array: unexpected token type: <" << get_opcode_name(token().opcode) << ">";
+                os << "array: unexpected token type: <" << get_formula_opcode_name(token().opcode) << ">";
                 throw invalid_expression(os.str());
             }
         }
