@@ -14,7 +14,6 @@
 #include <ixion/model_iterator.hpp>
 #include <ixion/named_expressions_iterator.hpp>
 #include <ixion/global.hpp>
-#include <ixion/macros.hpp>
 #include <ixion/interface/table_handler.hpp>
 #include <ixion/config.hpp>
 #include <ixion/matrix.hpp>
@@ -45,11 +44,99 @@ void test_size()
     cout << "* string_id_t: " << sizeof(string_id_t)
         << " (min:" << std::numeric_limits<string_id_t>::min()
         << "; max:" << std::numeric_limits<string_id_t>::max() << ")" << endl;
-    cout << "* celltype_t: " << sizeof(celltype_t) << endl;
+    cout << "* cell_t: " << sizeof(cell_t) << endl;
     cout << "* formula_cell: " << sizeof(formula_cell) << endl;
     cout << "* formula_tokens_t: " << sizeof(formula_tokens_t) << endl;
 }
 
+void test_formula_opcode_name()
+{
+    IXION_TEST_FUNC_SCOPE;
+
+    constexpr std::tuple<fopcode_t, std::string_view> checks[] =
+    {
+        { fop_unknown, "unknown" },
+        { fop_single_ref, "single-ref" },
+        { fop_range_ref, "range-ref" },
+        { fop_table_ref, "table-ref" },
+        { fop_named_expression, "named-expression" },
+        { fop_string, "string" },
+        { fop_value, "value" },
+        { fop_function, "function" },
+        { fop_error, "error" },
+        { fop_plus, "plus" },
+        { fop_minus, "minus" },
+        { fop_divide, "divide" },
+        { fop_multiply, "multiply" },
+        { fop_exponent, "exponent" },
+        { fop_concat, "concat" },
+        { fop_equal, "equal" },
+        { fop_not_equal, "not-equal" },
+        { fop_less, "less" },
+        { fop_greater, "greater" },
+        { fop_less_equal, "less-equal" },
+        { fop_greater_equal, "greater-equal" },
+        { fop_open, "open" },
+        { fop_close, "close" },
+        { fop_sep, "sep" },
+        { fop_array_row_sep, "array-row-sep" },
+        { fop_array_open, "array-open" },
+        { fop_array_close, "array-close" },
+        { fop_invalid_formula, "invalid-formula" },
+    };
+
+    for (const auto& [oc, expected] : checks)
+    {
+        if (auto actual = ixion::get_formula_opcode_name(oc); actual != expected)
+        {
+            std::cout << "expected opcode name was '" << expected
+                << "' but the actual value was '" << actual
+                << "' (opcode=" << int(oc) << ")"
+                << std::endl;
+
+            assert(false);
+        }
+    }
+}
+
+void test_formula_opcode_string()
+{
+    IXION_TEST_FUNC_SCOPE;
+
+    constexpr std::tuple<fopcode_t, std::string_view> checks[] =
+    {
+        { fop_plus, "+", },
+        { fop_minus, "-", },
+        { fop_divide, "/", },
+        { fop_multiply, "*", },
+        { fop_exponent, "^", },
+        { fop_concat, "&", },
+        { fop_equal, "=", },
+        { fop_not_equal, "<>", },
+        { fop_less, "<", },
+        { fop_greater, ">", },
+        { fop_less_equal, "<=", },
+        { fop_greater_equal, ">=", },
+        { fop_open, "(", },
+        { fop_close, ")", },
+        { fop_array_open, "{", },
+        { fop_array_close, "}", },
+    };
+
+    for (const auto& [oc, expected] : checks)
+    {
+        if (auto actual = ixion::get_formula_opcode_string(oc); actual != expected)
+        {
+            std::cout << "expected opcode string was '" << expected
+                << "' but the actual value was '" << actual
+                << "' (opcode=" << int(oc) << ")"
+                << std::endl;
+
+            assert(false);
+        }
+    }
+}
+
 void test_string_to_double()
 {
     IXION_TEST_FUNC_SCOPE;
@@ -416,7 +503,7 @@ void test_model_context_storage()
 
         // Test empty cell access.
         cell_access ca = cxt.get_cell_access(abs_address_t(0, 0, 0));
-        assert(ca.get_type() == celltype_t::empty);
+        assert(ca.get_type() == cell_t::empty);
         assert(ca.get_value_type() == cell_value_t::empty);
 
         // String value on an empty cell should be an empty string.
@@ -439,7 +526,7 @@ void test_model_context_storage()
                 assert(test == val);
 
                 ca = cxt.get_cell_access(pos);
-                assert(ca.get_type() == celltype_t::numeric);
+                assert(ca.get_type() == cell_t::numeric);
                 assert(ca.get_value_type() == cell_value_t::numeric);
                 test = ca.get_numeric_value();
                 assert(test == val);
@@ -462,7 +549,7 @@ void test_model_context_storage()
         p->interpret(cxt, pos);
 
         ca = cxt.get_cell_access(pos);
-        assert(ca.get_type() == celltype_t::formula);
+        assert(ca.get_type() == cell_t::formula);
         assert(ca.get_value_type() == cell_value_t::numeric);
         assert(ca.get_numeric_value() == 6.0);
     }
@@ -573,7 +660,7 @@ void test_model_context_direct_string_access()
     assert(s == "string cell");
 
     cell_access ca = cxt.get_cell_access(B2);
-    assert(ca.get_type() == celltype_t::string);
+    assert(ca.get_type() == cell_t::string);
     assert(ca.get_value_type() == cell_value_t::string);
     s = ca.get_string_value();
     assert(s == "string cell");
@@ -597,7 +684,7 @@ void test_model_context_direct_string_access()
     assert(s == "string value in formula");
 
     ca = cxt.get_cell_access(C4);
-    assert(ca.get_type() == celltype_t::formula);
+    assert(ca.get_type() == cell_t::formula);
     assert(ca.get_value_type() == cell_value_t::string);
     s = ca.get_string_value();
     assert(s == "string value in formula");
@@ -760,7 +847,7 @@ void test_model_context_iterator_horizontal()
             assert(iter.has());
             assert(iter.get().row == row);
             assert(iter.get().col == col);
-            assert(iter.get().type == celltype_t::empty);
+            assert(iter.get().type == cell_t::empty);
         }
     }
 
@@ -950,7 +1037,7 @@ void test_model_context_iterator_vertical()
             assert(iter.has());
             assert(cell.row == row);
             assert(cell.col == col);
-            assert(cell.type == celltype_t::empty);
+            assert(cell.type == cell_t::empty);
         }
     }
 
@@ -1294,7 +1381,7 @@ void test_model_context_error_value()
     fc->interpret(cxt, pos);
 
     cell_access ca = cxt.get_cell_access(pos);
-    assert(ca.get_type() == celltype_t::formula);
+    assert(ca.get_type() == cell_t::formula);
     assert(ca.get_value_type() == cell_value_t::error);
     assert(ca.get_error_value() == formula_error_t::division_by_zero);
 }
@@ -1424,7 +1511,7 @@ void test_invalid_formula_tokens()
 
     formula_tokens_t tokens = create_formula_error_tokens(cxt, invalid_formula, error_msg);
 
-    assert(tokens[0].opcode == fop_error);
+    assert(tokens[0].opcode == fop_invalid_formula);
     assert(tokens.size() == (std::get<string_id_t>(tokens[0].value) + 1));
 
     assert(tokens[1].opcode == fop_string);
@@ -1465,6 +1552,8 @@ void test_grouped_formula_string_results()
 int main()
 {
     test_size();
+    test_formula_opcode_name();
+    test_formula_opcode_string();
     test_string_to_double();
     test_string_pool();
     test_formula_tokens_store();
